@@ -42,7 +42,7 @@
 #include <sys/mman.h>
 #include <libgen.h>
 
-#include <http-parser/http_parser.h>
+#include <urlparse.h>
 
 #include "h09client.h"
 #include "network.h"
@@ -833,7 +833,7 @@ int Client::feed_data(const Endpoint &ep, const sockaddr *sa, socklen_t salen,
 }
 
 int Client::on_read(const Endpoint &ep) {
-  std::array<uint8_t, 64_k - 1> buf;
+  std::array<uint8_t, 64_k> buf;
   sockaddr_union su;
   size_t pktcnt = 0;
   ngtcp2_pkt_info pi;
@@ -1708,16 +1708,16 @@ int Client::select_preferred_address(Address &selected_addr,
     return -1;
   }
 
-  char host[NI_MAXHOST], service[NI_MAXSERV];
-  if (auto rv =
-        getnameinfo(&selected_addr.su.sa, selected_addr.len, host, sizeof(host),
-                    service, sizeof(service), NI_NUMERICHOST | NI_NUMERICSERV);
-      rv != 0) {
-    std::cerr << "getnameinfo: " << gai_strerror(rv) << std::endl;
-    return -1;
-  }
-
   if (!config.quiet) {
+    char host[NI_MAXHOST], service[NI_MAXSERV];
+    if (auto rv = getnameinfo(&selected_addr.su.sa, selected_addr.len, host,
+                              sizeof(host), service, sizeof(service),
+                              NI_NUMERICHOST | NI_NUMERICSERV);
+        rv != 0) {
+      std::cerr << "getnameinfo: " << gai_strerror(rv) << std::endl;
+      return -1;
+    }
+
     std::cerr << "selected server preferred_address is [" << host
               << "]:" << service << std::endl;
   }
@@ -1775,8 +1775,8 @@ int run(Client &c, const char *addr, const char *port,
 } // namespace
 
 namespace {
-std::string_view get_string(const char *uri, const http_parser_url &u,
-                            http_parser_url_fields f) {
+std::string_view get_string(const char *uri, const urlparse_url &u,
+                            urlparse_url_fields f) {
   auto p = &u.field_data[f];
   return {uri + p->off, p->len};
 }
@@ -1784,37 +1784,37 @@ std::string_view get_string(const char *uri, const http_parser_url &u,
 
 namespace {
 int parse_uri(Request &req, const char *uri) {
-  http_parser_url u;
+  urlparse_url u;
 
-  http_parser_url_init(&u);
-  if (http_parser_parse_url(uri, strlen(uri), /* is_connect = */ 0, &u) != 0) {
+  if (urlparse_parse_url(uri, strlen(uri), /* is_connect = */ 0, &u) != 0) {
     return -1;
   }
 
-  if (!(u.field_set & (1 << UF_SCHEMA)) || !(u.field_set & (1 << UF_HOST))) {
+  if (!(u.field_set & (1 << URLPARSE_SCHEMA)) ||
+      !(u.field_set & (1 << URLPARSE_HOST))) {
     return -1;
   }
 
-  req.scheme = get_string(uri, u, UF_SCHEMA);
+  req.scheme = get_string(uri, u, URLPARSE_SCHEMA);
 
-  req.authority = get_string(uri, u, UF_HOST);
+  req.authority = get_string(uri, u, URLPARSE_HOST);
   if (util::numeric_host(req.authority.c_str(), AF_INET6)) {
     req.authority = '[' + req.authority + ']';
   }
-  if (u.field_set & (1 << UF_PORT)) {
+  if (u.field_set & (1 << URLPARSE_PORT)) {
     req.authority += ':';
-    req.authority += get_string(uri, u, UF_PORT);
+    req.authority += get_string(uri, u, URLPARSE_PORT);
   }
 
-  if (u.field_set & (1 << UF_PATH)) {
-    req.path = get_string(uri, u, UF_PATH);
+  if (u.field_set & (1 << URLPARSE_PATH)) {
+    req.path = get_string(uri, u, URLPARSE_PATH);
   } else {
     req.path = "/";
   }
 
-  if (u.field_set & (1 << UF_QUERY)) {
+  if (u.field_set & (1 << URLPARSE_QUERY)) {
     req.path += '?';
-    req.path += get_string(uri, u, UF_QUERY);
+    req.path += get_string(uri, u, URLPARSE_QUERY);
   }
 
   return 0;
@@ -1863,11 +1863,9 @@ void config_set_default(Config &config) {
   config.version = NGTCP2_PROTO_VER_V1;
   config.timeout = 30 * NGTCP2_SECONDS;
   config.http_method = "GET"sv;
-  config.max_data = 15_m;
-  config.max_stream_data_bidi_local = 6_m;
-  config.max_stream_data_uni = 6_m;
-  config.max_window = 24_m;
-  config.max_stream_window = 16_m;
+  config.max_data = 24_m;
+  config.max_stream_data_bidi_local = 16_m;
+  config.max_stream_data_uni = 16_m;
   config.max_streams_uni = 100;
   config.cc_algo = NGTCP2_CC_ALGO_CUBIC;
   config.initial_rtt = NGTCP2_DEFAULT_INITIAL_RTT;
